==> xlniuxdata-jinzuan-1.0.7-20151217.075436-3-sources.jar: com/xunlei/niux/data/jinzuan/util/BonusUtil.java <==
package com.xunlei.niux.data.jinzuan.util;

import com.xunlei.niux.client.util.HttpClientUtil;
import com.xunlei.niux.client.util.SignUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;

/**
 * Created by lizeyu on 2015/12/10.
 */
public class BonusUtil{

    private static String bizNo = "00001";
    private static String bizPwd = "dsafdfasdfas";
    private static String bonusUrl = "http://123.151.31.240:7070";

    private static Logger logger = LoggerFactory
            .getLogger(BonusUtil.class.getName());

    public static void rechargeBonus(String userId, String userName, int transNum, String transNo, String balanceDate, String actNo){
        HashMap param = new HashMap();
        param.put("userId", userId);
        param.put("userName", userName);
        param.put("transNum", transNum + "");
        param.put("transNo", transNo);
        param.put("bizNo", bizNo);
        param.put("balanceDate", balanceDate);
        param.put("actNo", actNo == null ? "" : actNo);
        String sign = SignUtil.sign(param, bizPwd);
        String str = SignUtil.getSignatureContent(param);
        str = str + "&sign=" + sign;

        logger.info("bonusutil url:" + bonusUrl + "/recharge.do?" + str);
        String resp = HttpClientUtil.get(bonusUrl + "/recharge.do?" + str);
        logger.info("bonustil resp");
        if(!resp.contains("\"code\":\"00\"")){
            if(!resp.contains("\"code\":\"1001\"")){
                throw new RuntimeException(resp);
            }
        }

    }
}

==> xlniuxdata-jinzuan-1.0.7-20161014.034359-11-sources.jar: com/xunlei/niux/data/jinzuan/util/BonusUtil.java <==
package com.xunlei.niux.data.jinzuan.util;

import com.xunlei.niux.client.util.HttpClientUtil;
import com.xunlei.niux.client.util.SignUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.HashMap;

/**
 * Created by lizeyu on 2015/12/10.
 */
public class BonusUtil{

    private static String bizNo = "00001";
    private static String bizPwd = "dsafdfasdfas";
    private static String bonusUrl = "http://bonus.niu.xunlei.com:7070";

    private static Logger logger = LoggerFactory
            .getLogger(BonusUtil.class.getName());

    public static void rechargeBonus(String userId, String userName, int transNum, String transNo, String balanceDate, String actNo){
        HashMap param = new HashMap();
        param.put("userId", userId);
        param.put("userName", userName);
        param.put("transNum", transNum + "");
        param.put("transNo", transNo);
        param.put("bizNo", bizNo);
        param.put("balanceDate", balanceDate);
        param.put("actNo", actNo == null ? "" : actNo);
        String sign = SignUtil.sign(param, bizPwd);
        String str = SignUtil.getSignatureContent(param);
        str = str + "&sign=" + sign;

        logger.info("bonusutil url:" + bonusUrl + "/recharge.do?" + str);
        String resp = HttpClientUtil.get(bonusUrl + "/recharge.do?" + str);
        logger.info("bonustil resp");
        if(!resp.contains("\"code\":\"00\"")){
            if(!resp.contains("\"code\":\"1001\"")){
                throw new RuntimeException(resp);
            }
        }

    }
}
